# Workshop goal
The goal of this workshop is to guide the user through the first steps of creating their first workflow.
After completing this workshop the user should understand the basic steps of creating a product and the workflows
to manipulate that product.

#### Workshop overview
- Install the package and setup the database
- Setup and run the [orchestrator-core](https://github.com/workfloworchestrator/orchestrator-core) and [orchestrator-core-gui](https://github.com/workfloworchestrator/orchestrator-core-gui) projects together.
- Create your first product and domain model.
- Create your first workflow and input form


!!! note
    This workshop will guide the user through the basic principles of the orchestrator. For in depth questions please contact the [maintainers](mailto:automation-beheer@surf.nl)
